# common

## Objects

 * <span class="badge object-type-enum"></span> [AxisColorMode](./object-AxisColorMode.md)
 * <span class="badge object-type-class"></span> [AxisConfig](./object-AxisConfig.md)
 * <span class="badge object-type-enum"></span> [AxisPlacement](./object-AxisPlacement.md)
 * <span class="badge object-type-enum"></span> [BarAlignment](./object-BarAlignment.md)
 * <span class="badge object-type-class"></span> [BarConfig](./object-BarConfig.md)
 * <span class="badge object-type-enum"></span> [BarGaugeDisplayMode](./object-BarGaugeDisplayMode.md)
 * <span class="badge object-type-enum"></span> [BarGaugeNamePlacement](./object-BarGaugeNamePlacement.md)
 * <span class="badge object-type-enum"></span> [BarGaugeSizing](./object-BarGaugeSizing.md)
 * <span class="badge object-type-enum"></span> [BarGaugeValueMode](./object-BarGaugeValueMode.md)
 * <span class="badge object-type-class"></span> [BaseDimensionConfig](./object-BaseDimensionConfig.md)
 * <span class="badge object-type-enum"></span> [BigValueColorMode](./object-BigValueColorMode.md)
 * <span class="badge object-type-enum"></span> [BigValueGraphMode](./object-BigValueGraphMode.md)
 * <span class="badge object-type-enum"></span> [BigValueJustifyMode](./object-BigValueJustifyMode.md)
 * <span class="badge object-type-enum"></span> [BigValueTextMode](./object-BigValueTextMode.md)
 * <span class="badge object-type-class"></span> [ColorDimensionConfig](./object-ColorDimensionConfig.md)
 * <span class="badge object-type-enum"></span> [ComparisonOperation](./object-ComparisonOperation.md)
 * <span class="badge object-type-class"></span> [DataQuery](./object-DataQuery.md)
 * <span class="badge object-type-class"></span> [DataSourceJsonData](./object-DataSourceJsonData.md)
 * <span class="badge object-type-enum"></span> [FieldTextAlignment](./object-FieldTextAlignment.md)
 * <span class="badge object-type-class"></span> [FillConfig](./object-FillConfig.md)
 * <span class="badge object-type-class"></span> [FrameGeometrySource](./object-FrameGeometrySource.md)
 * <span class="badge object-type-enum"></span> [FrameGeometrySourceMode](./object-FrameGeometrySourceMode.md)
 * <span class="badge object-type-enum"></span> [GraphDrawStyle](./object-GraphDrawStyle.md)
 * <span class="badge object-type-class"></span> [GraphFieldConfig](./object-GraphFieldConfig.md)
 * <span class="badge object-type-enum"></span> [GraphGradientMode](./object-GraphGradientMode.md)
 * <span class="badge object-type-class"></span> [GraphThresholdsStyleConfig](./object-GraphThresholdsStyleConfig.md)
 * <span class="badge object-type-enum"></span> [GraphTransform](./object-GraphTransform.md)
 * <span class="badge object-type-enum"></span> [GraphTresholdsStyleMode](./object-GraphTresholdsStyleMode.md)
 * <span class="badge object-type-class"></span> [HeatmapCalculationBucketConfig](./object-HeatmapCalculationBucketConfig.md)
 * <span class="badge object-type-enum"></span> [HeatmapCalculationMode](./object-HeatmapCalculationMode.md)
 * <span class="badge object-type-class"></span> [HeatmapCalculationOptions](./object-HeatmapCalculationOptions.md)
 * <span class="badge object-type-enum"></span> [HeatmapCellLayout](./object-HeatmapCellLayout.md)
 * <span class="badge object-type-class"></span> [HideSeriesConfig](./object-HideSeriesConfig.md)
 * <span class="badge object-type-class"></span> [HideableFieldConfig](./object-HideableFieldConfig.md)
 * <span class="badge object-type-map"></span> [Labels](./object-Labels.md)
 * <span class="badge object-type-enum"></span> [LegendDisplayMode](./object-LegendDisplayMode.md)
 * <span class="badge object-type-enum"></span> [LegendPlacement](./object-LegendPlacement.md)
 * <span class="badge object-type-class"></span> [LineConfig](./object-LineConfig.md)
 * <span class="badge object-type-enum"></span> [LineInterpolation](./object-LineInterpolation.md)
 * <span class="badge object-type-class"></span> [LineStyle](./object-LineStyle.md)
 * <span class="badge object-type-enum"></span> [LogsDedupStrategy](./object-LogsDedupStrategy.md)
 * <span class="badge object-type-enum"></span> [LogsSortOrder](./object-LogsSortOrder.md)
 * <span class="badge object-type-class"></span> [MapLayerOptions](./object-MapLayerOptions.md)
 * <span class="badge object-type-class"></span> [OptionsWithLegend](./object-OptionsWithLegend.md)
 * <span class="badge object-type-class"></span> [OptionsWithTextFormatting](./object-OptionsWithTextFormatting.md)
 * <span class="badge object-type-class"></span> [OptionsWithTimezones](./object-OptionsWithTimezones.md)
 * <span class="badge object-type-class"></span> [OptionsWithTooltip](./object-OptionsWithTooltip.md)
 * <span class="badge object-type-class"></span> [PointsConfig](./object-PointsConfig.md)
 * <span class="badge object-type-class"></span> [ReduceDataOptions](./object-ReduceDataOptions.md)
 * <span class="badge object-type-class"></span> [ResourceDimensionConfig](./object-ResourceDimensionConfig.md)
 * <span class="badge object-type-enum"></span> [ResourceDimensionMode](./object-ResourceDimensionMode.md)
 * <span class="badge object-type-class"></span> [ScalarDimensionConfig](./object-ScalarDimensionConfig.md)
 * <span class="badge object-type-enum"></span> [ScalarDimensionMode](./object-ScalarDimensionMode.md)
 * <span class="badge object-type-class"></span> [ScaleDimensionConfig](./object-ScaleDimensionConfig.md)
 * <span class="badge object-type-enum"></span> [ScaleDimensionMode](./object-ScaleDimensionMode.md)
 * <span class="badge object-type-enum"></span> [ScaleDirection](./object-ScaleDirection.md)
 * <span class="badge object-type-enum"></span> [ScaleDistribution](./object-ScaleDistribution.md)
 * <span class="badge object-type-class"></span> [ScaleDistributionConfig](./object-ScaleDistributionConfig.md)
 * <span class="badge object-type-enum"></span> [ScaleOrientation](./object-ScaleOrientation.md)
 * <span class="badge object-type-class"></span> [SingleStatBaseOptions](./object-SingleStatBaseOptions.md)
 * <span class="badge object-type-enum"></span> [SortOrder](./object-SortOrder.md)
 * <span class="badge object-type-class"></span> [StackableFieldConfig](./object-StackableFieldConfig.md)
 * <span class="badge object-type-class"></span> [StackingConfig](./object-StackingConfig.md)
 * <span class="badge object-type-enum"></span> [StackingMode](./object-StackingMode.md)
 * <span class="badge object-type-class"></span> [TableAutoCellOptions](./object-TableAutoCellOptions.md)
 * <span class="badge object-type-class"></span> [TableBarGaugeCellOptions](./object-TableBarGaugeCellOptions.md)
 * <span class="badge object-type-enum"></span> [TableCellBackgroundDisplayMode](./object-TableCellBackgroundDisplayMode.md)
 * <span class="badge object-type-enum"></span> [TableCellDisplayMode](./object-TableCellDisplayMode.md)
 * <span class="badge object-type-enum"></span> [TableCellHeight](./object-TableCellHeight.md)
 * <span class="badge object-type-disjunction"></span> [TableCellOptions](./object-TableCellOptions.md)
 * <span class="badge object-type-class"></span> [TableColorTextCellOptions](./object-TableColorTextCellOptions.md)
 * <span class="badge object-type-class"></span> [TableColoredBackgroundCellOptions](./object-TableColoredBackgroundCellOptions.md)
 * <span class="badge object-type-class"></span> [TableFieldOptions](./object-TableFieldOptions.md)
 * <span class="badge object-type-class"></span> [TableFooterOptions](./object-TableFooterOptions.md)
 * <span class="badge object-type-class"></span> [TableImageCellOptions](./object-TableImageCellOptions.md)
 * <span class="badge object-type-class"></span> [TableJsonViewCellOptions](./object-TableJsonViewCellOptions.md)
 * <span class="badge object-type-class"></span> [TableSortByFieldState](./object-TableSortByFieldState.md)
 * <span class="badge object-type-class"></span> [TableSparklineCellOptions](./object-TableSparklineCellOptions.md)
 * <span class="badge object-type-class"></span> [TextDimensionConfig](./object-TextDimensionConfig.md)
 * <span class="badge object-type-enum"></span> [TextDimensionMode](./object-TextDimensionMode.md)
 * <span class="badge object-type-scalar"></span> [TimeZone](./object-TimeZone.md)
 * <span class="badge object-type-scalar"></span> [TimeZoneBrowser](./object-TimeZoneBrowser.md)
 * <span class="badge object-type-scalar"></span> [TimeZoneUtc](./object-TimeZoneUtc.md)
 * <span class="badge object-type-enum"></span> [TimelineValueAlignment](./object-TimelineValueAlignment.md)
 * <span class="badge object-type-enum"></span> [TooltipDisplayMode](./object-TooltipDisplayMode.md)
 * <span class="badge object-type-enum"></span> [VariableFormatID](./object-VariableFormatID.md)
 * <span class="badge object-type-enum"></span> [VisibilityMode](./object-VisibilityMode.md)
 * <span class="badge object-type-class"></span> [VizLegendOptions](./object-VizLegendOptions.md)
 * <span class="badge object-type-enum"></span> [VizOrientation](./object-VizOrientation.md)
 * <span class="badge object-type-class"></span> [VizTextDisplayOptions](./object-VizTextDisplayOptions.md)
 * <span class="badge object-type-class"></span> [VizTooltipOptions](./object-VizTooltipOptions.md)
## Builders

 * <span class="badge builder"></span> [AxisConfig](./builder-AxisConfig.md)
 * <span class="badge builder"></span> [BarConfig](./builder-BarConfig.md)
 * <span class="badge builder"></span> [BaseDimensionConfig](./builder-BaseDimensionConfig.md)
 * <span class="badge builder"></span> [ColorDimensionConfig](./builder-ColorDimensionConfig.md)
 * <span class="badge builder"></span> [DataQuery](./builder-DataQuery.md)
 * <span class="badge builder"></span> [DataSourceJsonData](./builder-DataSourceJsonData.md)
 * <span class="badge builder"></span> [FillConfig](./builder-FillConfig.md)
 * <span class="badge builder"></span> [FrameGeometrySource](./builder-FrameGeometrySource.md)
 * <span class="badge builder"></span> [GraphFieldConfig](./builder-GraphFieldConfig.md)
 * <span class="badge builder"></span> [GraphThresholdsStyleConfig](./builder-GraphThresholdsStyleConfig.md)
 * <span class="badge builder"></span> [HeatmapCalculationBucketConfig](./builder-HeatmapCalculationBucketConfig.md)
 * <span class="badge builder"></span> [HeatmapCalculationOptions](./builder-HeatmapCalculationOptions.md)
 * <span class="badge builder"></span> [HideSeriesConfig](./builder-HideSeriesConfig.md)
 * <span class="badge builder"></span> [HideableFieldConfig](./builder-HideableFieldConfig.md)
 * <span class="badge builder"></span> [LineConfig](./builder-LineConfig.md)
 * <span class="badge builder"></span> [LineStyle](./builder-LineStyle.md)
 * <span class="badge builder"></span> [MapLayerOptions](./builder-MapLayerOptions.md)
 * <span class="badge builder"></span> [OptionsWithLegend](./builder-OptionsWithLegend.md)
 * <span class="badge builder"></span> [OptionsWithTextFormatting](./builder-OptionsWithTextFormatting.md)
 * <span class="badge builder"></span> [OptionsWithTimezones](./builder-OptionsWithTimezones.md)
 * <span class="badge builder"></span> [OptionsWithTooltip](./builder-OptionsWithTooltip.md)
 * <span class="badge builder"></span> [PointsConfig](./builder-PointsConfig.md)
 * <span class="badge builder"></span> [ReduceDataOptions](./builder-ReduceDataOptions.md)
 * <span class="badge builder"></span> [ResourceDimensionConfig](./builder-ResourceDimensionConfig.md)
 * <span class="badge builder"></span> [ScalarDimensionConfig](./builder-ScalarDimensionConfig.md)
 * <span class="badge builder"></span> [ScaleDimensionConfig](./builder-ScaleDimensionConfig.md)
 * <span class="badge builder"></span> [ScaleDistributionConfig](./builder-ScaleDistributionConfig.md)
 * <span class="badge builder"></span> [SingleStatBaseOptions](./builder-SingleStatBaseOptions.md)
 * <span class="badge builder"></span> [StackableFieldConfig](./builder-StackableFieldConfig.md)
 * <span class="badge builder"></span> [StackingConfig](./builder-StackingConfig.md)
 * <span class="badge builder"></span> [TableFieldOptions](./builder-TableFieldOptions.md)
 * <span class="badge builder"></span> [TableFooterOptions](./builder-TableFooterOptions.md)
 * <span class="badge builder"></span> [TableSortByFieldState](./builder-TableSortByFieldState.md)
 * <span class="badge builder"></span> [TextDimensionConfig](./builder-TextDimensionConfig.md)
 * <span class="badge builder"></span> [VizLegendOptions](./builder-VizLegendOptions.md)
 * <span class="badge builder"></span> [VizTextDisplayOptions](./builder-VizTextDisplayOptions.md)
 * <span class="badge builder"></span> [VizTooltipOptions](./builder-VizTooltipOptions.md)
